#!/usr/bin/python
# encoding: utf-8
#
# Copyright (c) 2019 Dean Jackson <deanishe@deanishe.net>
#
# MIT Licence. See http://opensource.org/licenses/MIT
#
# Created on 2019-06-03
#

"""Put selected files in a new directory."""

from __future__ import print_function, absolute_import

import os
import sys


def log(s, *args):
    """Simple STDERR logger."""
    if args:
        s = s % args
    print(s, file=sys.stderr)


def in_same_dir(paths):
    """Return `True` if all `paths` are in the same directory."""
    dirs = set([os.path.dirname(p) for p in paths])
    return len(dirs) == 1


def newname(dirname):
    """Return non-existent filename."""
    p = os.path.join(dirname, 'New Folder')
    n = 1
    while os.path.exists(p):
        p = os.path.join(dirname, 'New Folder (%d)' % n)
        n += 1

    return p


def main():
    """Run script."""
    paths = sys.argv[1:]
    for p in paths:
        log('path=%r', p)

    if not in_same_dir(paths):
        log('[ERROR] selected files are in different directories')
        print('Selected files not in same directories')
        return 1

    parent = os.path.dirname(paths[0])
    newdir = newname(parent)
    os.makedirs(newdir, mode=0755)
    for p in paths:
        np = os.path.join(newdir, os.path.basename(p))
        os.rename(p, np)
        log('renamed %r  -->  %r', p, np)


if __name__ == "__main__":
    import traceback
    try:
        sys.exit(main())
    except Exception as err:
        print(str(err))
        traceback.print_exc()
        
